@@ -41,7 +41,7 @@ module Puppet::Util::Plist
 
         Puppet.debug "Plist #{file_path} ill-formatted, converting with plutil"
         begin
-          plist = Puppet::Util::Execution.execute(['/usr/bin/plutil', '-convert', 'xml1', '-o', '/dev/stdout', file_path],
+          plist = Puppet::Util::Execution.execute(['/usr/bin/plutil', '-convert', 'xml1', '-o', '-', file_path],
                                                   {:failonfail => true, :combine => true})
           return parse_plist(plist)
         rescue Puppet::ExecutionFailure => detail
@@ -124,11 +124,11 @@ module Puppet::Util::Plist
 
     def to_format(format)
       if format.to_sym == :xml
-        plist_format = CFPropertyList::List::FORMAT_XML
+        CFPropertyList::List::FORMAT_XML
       elsif format.to_sym == :binary
-        plist_format = CFPropertyList::List::FORMAT_BINARY
+        CFPropertyList::List::FORMAT_BINARY
       elsif format.to_sym == :plain
-        plist_format = CFPropertyList::List::FORMAT_PLAIN
+        CFPropertyList::List::FORMAT_PLAIN
       else
         raise FormatError.new "Unknown plist format #{format}"
       end
